#
%define         mongo_home /var/lib/mongo
#
Name:           Percona-Server-MongoDB-32
Version:        3.2.17
Release:        3.8%{?dist}
Summary:        High-performance MongoDB replacement from Percona (metapackage)
Group:          Applications/Databases

License:        AGPL
URL:            https://github.com/percona/percona-server-mongodb.git
Source0:        percona-server-mongodb-3.2.17-3.8.tar.gz
Source1:        mongod.conf
Source2:        mongod.service
Source3:        mongod.default
Source4:        percona-server-mongodb-helper.sh
Source5:        mongod.init
Source6:        mongod.pp

%if 0%{?rhel} > 6
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
%else
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig
Requires(preun):  /sbin/service
%endif


BuildRoot:      /var/tmp/%{name}-%{version}-%{release}
%undefine       _missing_build_ids_terminate_build
%define         _unpackaged_files_terminate_build 0

%if 0%{?rhel} > 6
%global _dwz_low_mem_die_limit 0
%endif

%define         src_dir ./percona-server-mongodb-3.2.17-3.8

BuildRequires: gcc, make, cmake, gcc-c++, openssl-devel, cyrus-sasl-devel
BuildRequires: snappy-devel, zlib-devel, bzip2-devel
BuildRequires: /usr/bin/scons

# %if 0%{?rhel} >= 6
# BuildRequires: policycoreutils-python
# %endif

Requires: %{name}-mongos = %{version}-%{release}
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-shell = %{version}-%{release}
Requires: %{name}-tools = %{version}-%{release}
Requires: numactl

Conflicts: Percona-Server-MongoDB mongodb-org

%description
This package contains high-performance MongoDB replacement from Percona - Percona Server for MongoDB.
Percona Server for MongoDB is built for scalability, performance and high availability, scaling from single server deployments to large, complex multi-site architectures. By leveraging in-memory computing, Percona Server for MongoDB provides high performance for both reads and writes. Percona Server for MongoDB's native replication and automated failover enable enterprise-grade reliability and operational flexibility.

Percona Server for MongoDB is an open-source database used by companies of all sizes, across all industries and for a wide variety of applications. It is an agile database that allows schemas to change quickly as applications evolve, while still providing the functionality developers expect from traditional databases, such as secondary indexes, a full query language and strict consistency.

Percona Server for MongoDB has a rich client ecosystem including hadoop integration, officially supported drivers for 10 programming languages and environments, as well as 40 drivers supported by the user community.

Percona Server for MongoDB features:
* JSON Data Model with Dynamic Schemas
* Auto-Sharding for Horizontal Scalability
* Built-In Replication for High Availability
* Rich Secondary Indexes, including geospatial
* TTL indexes
* Text Search
* Aggregation Framework & Native MapReduce

This metapackage will install the mongo shell, import/export tools, other client utilities, server software, default configuration, and init.d scripts.

%package mongos
Group:          Applications/Databases
Summary:        Percona Server for MongoDB sharded cluster query router
%description mongos
This package contains mongos - the Percona Server for MongoDB sharded cluster query router
Conflicts: Percona-Server-MongoDB-mongos mongodb-org-mongos

%package server
Group:          Applications/Databases
Summary:        Percona Server for MongoDB database server
Requires: policycoreutils
%description server
This package contains the Percona Server for MongoDB server software, default configuration files and init.d scripts
Conflicts: Percona-Server-MongoDB-server mongodb-org-server

%package shell
Group:          Applications/Databases
Summary:        Percona Server for MongoDB shell client
%description shell
This package contains the Percona Server for MongoDB shell
Conflicts: Percona-Server-MongoDB-shell mongodb-org-shell

%package tools
Group:          Applications/Databases
Summary:        The tools package for Percona Server for MongoDB
%description tools
This package contains various tools from MongoDB project, recompiled for Percona Server for MongoDB
Conflicts: Percona-Server-MongoDB-tools mongodb-org-tools

%prep

%setup -q -n %{src_dir}

%build

export CC=${CC:-gcc}
export CXX=${CXX:-g++}
export PSM_TARGETS="mongod mongos mongo"
export INSTALLDIR=$RPM_BUILD_DIR/install
export TOOLS_TAGS="ssl sasl"
export PORTABLE=1
export PATH=/usr/local/go/bin:$PATH

# TokuBackup
pushd $RPM_BUILD_DIR/%{src_dir}/src/third_party/Percona-TokuBackup/backup
cmake -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/ -DBUILD_STATIC_LIBRARY=ON
make -j4
make install DESTDIR=${INSTALLDIR}
popd

# PerconaFT
pushd $RPM_BUILD_DIR/%{src_dir}/src/third_party/PerconaFT
cmake . -DCMAKE_BUILD_TYPE=Release -DUSE_VALGRIND=OFF -DTOKU_DEBUG_PARANOID=OFF \
-DBUILD_TESTING=OFF -DCMAKE_INSTALL_PREFIX=/ -DJEMALLOC_SOURCE_DIR=$RPM_BUILD_DIR/%{src_dir}/src/third_party/jemalloc
%{__make} %{?_smp_mflags}
%{__make} install DESTDIR=${INSTALLDIR}
popd

# RocksDB
pushd $RPM_BUILD_DIR/%{src_dir}/src/third_party/rocksdb
rm -rf lz4-r127 || true
wget https://codeload.github.com/Cyan4973/lz4/tar.gz/r127
mv r127 lz4-r127.tar.gz
tar xvzf lz4-r127.tar.gz
pushd lz4-r127/lib
%{__make} CFLAGS=' -O3 -I. -std=c99 -Wall -Wextra -Wundef -Wshadow -Wcast-align -Wstrict-prototypes -pedantic -fPIC' all
popd
cp ./lz4-r127/lib/liblz4.a .
cp ./lz4-r127/lib/lz4.h ${INSTALLDIR}/include
cp ./lz4-r127/lib/lz4frame.h ${INSTALLDIR}/include
cp ./lz4-r127/lib/lz4hc.h ${INSTALLDIR}/include
cp ./lz4-r127/lib/liblz4.a ${INSTALLDIR}/lib
%{__make} %{?_smp_mflags} static_lib
%{__make} install-static INSTALL_PATH=${INSTALLDIR}
popd

# Build PSfMDB with SCons
pushd $RPM_BUILD_DIR/%{src_dir}
scons CC=${CC} CXX=${CXX} --audit --release --ssl --opt=on  \
%{?_smp_mflags} --use-sasl-client CPPPATH=${INSTALLDIR}/include LIBPATH=${INSTALLDIR}/lib \
--PerconaFT --rocksdb --wiredtiger --inmemory --tokubackup --hotbackup ${PSM_TARGETS}
popd

# Mongo Tools compilation
pushd $RPM_BUILD_DIR/%{src_dir}/mongo-tools
. ./set_gopath.sh
. ./set_tools_revision.sh
rm -rf $RPM_BUILD_DIR/%{src_dir}/mongo-tools/vendor/pkg
mkdir -p $RPM_BUILD_DIR/%{src_dir}/bin
for tool in bsondump mongostat mongofiles mongoexport mongoimport mongorestore mongodump mongotop mongooplog; do
  go build -a -x -o $RPM_BUILD_DIR/%{src_dir}/bin/${tool} -ldflags "-X github.com/mongodb/mongo-tools/common/options.Gitspec=${PSMDB_TOOLS_COMMIT_HASH} -X github.com/mongodb/mongo-tools/common/options.VersionStr=${PSMDB_TOOLS_REVISION}" -tags "${TOOLS_TAGS}" $RPM_BUILD_DIR/%{src_dir}/mongo-tools/${tool}/main/${tool}.go
done
popd

%install
#
rm -rf %{buildroot}
#
install -m 755 -d %{buildroot}/etc/selinux/targeted/modules/active/modules
install -m 644 %{SOURCE6} %{buildroot}/etc/selinux/targeted/modules/active/modules/
#
install -m 755 -d %{buildroot}/%{_bindir}
install -m 755 -d %{buildroot}/%{_sysconfdir}
install -m 755 -d %{buildroot}/%{_mandir}/man1

install -m 750 -d %{buildroot}/var/log/mongo
touch %{buildroot}/var/log/mongo/mongod.log
install -m 750 -d %{buildroot}/%{mongo_home}
install -m 755 -d %{buildroot}/%{_sysconfdir}/sysconfig
#
install -m 644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/mongod.conf
sed -i 's:mongodb:mongo:g' %{buildroot}/%{_sysconfdir}/mongod.conf
# startup stuff
%if 0%{?rhel} >= 7
  install -m 755 -d %{buildroot}/%{_unitdir}
  install -m 644 %{SOURCE2} %{buildroot}/%{_unitdir}/mongod.service
%else
  install -m 755 -d %{buildroot}/etc/rc.d/init.d
  install -m 750 %{SOURCE5} %{buildroot}/etc/rc.d/init.d/mongod
%endif
#
install -m 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/mongod
install -m 755 %{SOURCE4} %{buildroot}/%{_bindir}/
#
install -m 755 mongo %{buildroot}/%{_bindir}/
install -m 755 mongod %{buildroot}/%{_bindir}/
install -m 755 mongos %{buildroot}/%{_bindir}/

install -m 755 $RPM_BUILD_DIR/%{src_dir}/bin/* %{buildroot}/%{_bindir}/

install -m 644 $RPM_BUILD_DIR/%{src_dir}/manpages/* %{buildroot}/%{_mandir}/man1/

%files

%files mongos
%defattr(-,root,root,-)
%{_bindir}/mongos
%{_mandir}/man1/mongos.1.gz

%files server
%defattr(-,root,root,-)
%{_bindir}/mongod
%{_mandir}/man1/mongod.1.gz
%{_bindir}/percona-server-mongodb-helper.sh
%if 0%{?rhel} >= 7
%{_unitdir}/mongod.service
%else
/etc/rc.d/init.d/mongod
%endif
/etc/selinux/targeted/modules/active/modules/mongod.pp
%attr(0750,mongod,mongod) %dir %{mongo_home}
%attr(0750,mongod,mongod) %dir /var/log/mongo
%config(noreplace) %{_sysconfdir}/mongod.conf
%config(noreplace) %{_sysconfdir}/sysconfig/mongod
%attr(0640,mongod,mongod) %ghost /var/log/mongo/mongod.log
%doc GNU-AGPL-3.0 README THIRD-PARTY-NOTICES

%files shell
%defattr(-,root,root,-)
%{_bindir}/mongo
%{_mandir}/man1/mongo.1.gz

%files tools
%defattr(-,root,root,-)
%{_bindir}/bsondump
%{_mandir}/man1/bsondump.1.gz
%{_bindir}/mongostat
%{_mandir}/man1/mongostat.1.gz
%{_bindir}/mongofiles
%{_mandir}/man1/mongofiles.1.gz
%{_bindir}/mongoexport
%{_mandir}/man1/mongoexport.1.gz
%{_bindir}/mongoimport
%{_mandir}/man1/mongoimport.1.gz
%{_bindir}/mongorestore
%{_mandir}/man1/mongorestore.1.gz
%{_bindir}/mongodump
%{_mandir}/man1/mongodump.1.gz
%{_bindir}/mongotop
%{_mandir}/man1/mongotop.1.gz
%{_bindir}/mongooplog
%{_mandir}/man1/mongooplog.1.gz

%pre server
if [ $1 == 1 ]; then
  if ! getent passwd mongod > /dev/null 2>&1; then
    /usr/sbin/groupadd -r mongod
    /usr/sbin/useradd -M -r -g mongod -d %{mongo_home} -s /bin/false -c mongod mongod > /dev/null 2>&1
  fi
fi
#

%post server
#
%if 0%{?rhel} >= 7
%systemd_post mongod.service
  if [ $1 == 1 ]; then
    /usr/bin/systemctl enable mongod >/dev/null 2>&1 || :
  fi
%else
  if [ $1 == 1 ]; then
      /sbin/chkconfig --add mongod
  fi
%endif
%if 0%{?rhel} > 5
/usr/sbin/semodule -i /etc/selinux/targeted/modules/active/modules/mongod.pp
%else
/usr/sbin/semodule -i /etc/selinux/targeted/modules/active/modules/mongod.pp 2> /dev/null
%endif
echo " * To start the service, configure your engine and start mongod"

%preun server
%if 0%{?rhel} >= 7
%systemd_preun mongod.service
%else
if [ -x %{_sysconfdir}/init.d/mongod ] ; then
  %{_sysconfdir}/init.d/mongod stop
fi
%endif

%postun server
%if 0%{?rhel} >= 7
%systemd_postun mongod.service
%endif
if [ $1 == 0 ]; then
  if /usr/bin/id -g mongod > /dev/null 2>&1; then
    /usr/sbin/userdel mongod > /dev/null 2>&1
    /usr/sbin/groupdel mongod > /dev/null 2>&1 || true
  fi
fi

#
%changelog

* Thu Apr 07 2016 Alexey Bychko <alexey.bychko@percona.com> 3.2.4
- Percona Server for MongoDB v3.2.4 RC

* Fri Sep 18 2015 Alexey Bychko <alexey.bychko@percona.com> 3.0.5
- Percona Server for MongoDB RC 7

* Fri May 22 2015 Alexey Bychko <alexey.bychko@percona.com> 3.0
- Initial RPM release for Percona Server for MongoDB
